@@ -1,11 +1,9 @@
 import unittest
-import doctest
-
-from zope.testing import doctestunit
 from Testing import ZopeTestCase as ztc
 
 from collective.geo.contentlocations.tests import base
 
+
 def test_suite():
     """This sets up a test suite that actually runs the tests in the class
     above
@@ -14,7 +12,11 @@ def test_suite():
 
         ztc.ZopeDocFileSuite(
             'README.txt', package='collective.geo.contentlocations',
-            test_class=base.ContentlocationsFunctionalTestCase,
+            test_class=base.FunctionalTestCase,
+            ),
+        ztc.ZopeDocFileSuite(
+            'geostylemanager.txt', package='collective.geo.contentlocations',
+            test_class=base.FunctionalTestCase,
             ),
 
-        ])
\ No newline at end of file
+        ])
